/*******************************************************************************
 * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Marc R. Hoffmann - initial API and implementation
 *    
 *******************************************************************************/
package org.jacoco.core.test.validation;

import org.jacoco.core.analysis.ICounter;
import org.jacoco.core.test.validation.targets.Target06;
import org.junit.Test;

/**
 * Test of a implicit default constructor.
 */
public class ImplicitDefaultConstructorTest extends ValidationTestBase {

	public ImplicitDefaultConstructorTest() {
		super(Target06.class);
	}

	@Test
	public void testCoverageResult() {

		assertLine("classdef", ICounter.FULLY_COVERED);

	}

}
